@@ -27,7 +27,7 @@ How to use: Script is used through the create_circos_data() and make_diagram() m
 
 ############################### create_circos_data #############################
 
-def create_circos_data(contigs, output_dir, project_title, hmm_db, e_value=0.01, min_contig_length=10000, min_blast_similarity_percentage=90, min_blast_similarity_length=300, link_transperacny='0.60', percent_link_overlap_tolerance=50, include_domains=True, gc=True, gc_interval_len=100, blast_type='blastn', keep_blast_data=False):
+def create_circos_data(contigs, output_dir, project_title, hmm_db='', e_value=0.01, min_contig_length=10000, min_blast_similarity_percentage=90, min_blast_similarity_length=300, link_transperacny='0.60', percent_link_overlap_tolerance=50, include_domains=False, gc=True, gc_interval_len=100, blast_type='blastn', keep_blast_data=False):
     """
     Create the following input files for a circos diagram:
         - ORF.txt
@@ -78,6 +78,8 @@ def create_circos_data(contigs, output_dir, project_title, hmm_db, e_value=0.01,
 
     # links data
     links_df = links.get_link_data(list_of_correct_len_contigs_paths, blast_type, project_directory, min_blast_similarity_percentage, min_blast_similarity_length, link_transperacny, percent_link_overlap_tolerance, keep_blast_data)
+    if links_df.empty:
+        print('No links were found.')
     links_df.to_csv(project_directory + '/circos_diagram_input_data/links.txt', sep=' ', index=False, header=False)
 
     # orf data
@@ -185,7 +187,7 @@ def write_paramters_log(project_directory, contigs, output_dir, project_title, h
 
 #################### make_diagram ##############################################
 
-def make_diagram(data_dir, ncol):
+def make_diagram(data_dir, ncol=2):
     """
     Makes call to circos to make the diagram.
     Creates the protein domain and karyotype legends.
